"""Documentation configuration for `lembas`."""
from __future__ import annotations

from datetime import datetime

import lembas

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "myst_parser",
    "sphinx.ext.doctest",
    "sphinx.ext.intersphinx",
    "sphinx.ext.coverage",
    "sphinx.ext.mathjax",
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.viewcode",
    "sphinx_autodoc_typehints",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
source_suffix = [".rst", ".md"]

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "lembas"
author = "Matt Kramer"
copyright = f"2022 - {datetime.now().year}, {author}"
version = lembas.__version__
release = version

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
language = "en"

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

autodoc_default_options = {
    "members": None,
    "undoc-members": None,
    "show-inheritance": None,
}

# The theme to use for HTML and HTML Help pages.
html_theme = "pydata_sphinx_theme"
html_logo = "_static/logo.svg"
html_favicon = "_static/favicon.svg"
html_theme_options = {
    "github_url": "https://github.com/lembas-project/lembas-core",
    "icon_links": [
        {
            "name": "PyPI",
            "url": "https://pypi.org/project/lembas",
            "icon": "fas fa-box",
        },
    ],
}
html_static_path = ["_static"]
